/*
 * Copyright 2023 Richard Hughes <richard@hughsie.com>
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#pragma once

#define __PASSIM_H_INSIDE__

#include <passim-client.h>
#include <passim-item.h>
#include <passim-version.h>

#undef __PASSIM_H_INSIDE__
