body {
  font-family: Arial, Helvetica, sans-serif;
  padding: 20px 20px 20px 20px;
}
th {
  text-align: left;
}
tr:nth-child(even) {
  background-color: #f2f2f2;
}
table, th, td {
  border: 1px solid #f2f2f2;
  border-collapse: collapse;
}
th, td {
  padding: 10px;
}
